@@ -162,12 +162,13 @@ class interface(abstract_instrument_interface.abstract_interface):
         self.logger.info(f"Will move by {movement}. Begin moving...")
         self.instrument.move_by(movement)
         self.gui.set_moving_state()
-        self.wait_until_property_is_false(self.instrument,pyThorlabsAPT.is_in_motion,[self.end_movement])
-        self.wait_until_property_is_false(self.instrument,pyThorlabsAPT.is_in_motion,[self.gui.set_non_moving_state])
+        #Start checking periodically the value of self.instrument.is_in_motion/. When it becomes False, call self.end_movement
+        self.check_property_until(self.instrument,pyThorlabsAPT.is_in_motion,[False],[[self.end_movement]])
         
     def end_movement(self):
         self.read_position()
         self.logger.info(f"Movement ended. New position = {self.output['Position']}")
+        self.gui.set_non_moving_state
 
     def read_stage_info(self):
         #From the thorlabs_APT code:
@@ -234,6 +235,7 @@ class interface(abstract_instrument_interface.abstract_interface):
         action =[]
         if initial_trigger:
             action.append({'action':'send_trigger'})
+            action.append({'action':'wait', 'time':wait2})
         for j in range(repeat_ramp): #when repeat_ramp > 1, the whole ramp is repeated multiple times
             for i in range(numb_steps):
                 action.append({'action':'move', 'stepsize':stepsize})
@@ -365,7 +367,7 @@ class gui(abstract_instrument_interface.abstract_gui):
         ramp_vbox = Qt.QVBoxLayout()
         ramp_hbox1 = Qt.QHBoxLayout()
         ramp_hbox2 = Qt.QHBoxLayout()
-        self.checkbox_Initial_trigger = Qt.QCheckBox("Send initial trigger,")
+        self.checkbox_Initial_trigger = Qt.QCheckBox("Send initial trigger (+wait)")
         tooltip = 'When this interface is used within a larger software, it can be set to send a trigger (to another function) everytime a step of the ramp is done (see documentation).\nBy ticking this on, a trigger is sent also at the beginning of the ramp.'
         self.checkbox_Initial_trigger.setToolTip(tooltip)
         self.label_Move_ramp = Qt.QLabel("Move by")
@@ -528,7 +530,7 @@ class MainWindow(Qt.QWidget):
         # self.setCentralWidget(self.container)
     def closeEvent(self, event):
         if self.child:
-            self.child.close()
+            pass#self.child.close()
 
 def main():
     parser = argparse.ArgumentParser(description = "",epilog = "")
